"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  mergeProps: () => import_core.mergeProps,
  normalizeProps: () => normalizeProps,
  useActor: () => useActor,
  useMachine: () => useMachine,
  useSnapshot: () => useSnapshot
});
module.exports = __toCommonJS(src_exports);
var import_core = require("@zag-js/core");

// src/normalize-props.ts
var import_types = require("@zag-js/types");
function toCase(txt) {
  return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
}
var propMap = {
  htmlFor: "for",
  className: "class",
  onDoubleClick: "onDblclick",
  onChange: "onInput",
  onFocus: "onFocusin",
  onBlur: "onFocusout",
  defaultValue: "value",
  defaultChecked: "checked"
};
function toVueProp(prop) {
  if (prop in propMap)
    return propMap[prop];
  if (prop.startsWith("on")) {
    return `on${toCase(prop.substr(2))}`;
  }
  return prop.toLowerCase();
}
var normalizeProps = (0, import_types.createNormalizer)((props) => {
  const normalized = {};
  for (const key in props) {
    const value = props[key];
    if (key === "children") {
      if (typeof value === "string") {
        normalized["innerHTML"] = value;
      } else if (process.env.NODE_ENV !== "production" && value != null) {
        console.warn("[Vue Normalize Prop] : avoid passing non-primitive value as `children`");
      }
    } else {
      normalized[toVueProp(key)] = props[key];
    }
  }
  return normalized;
});

// src/use-snapshot.ts
var import_store = require("@zag-js/store");
var import_vue = require("vue");
function useSnapshot(service, options) {
  const { actions, context } = options ?? {};
  const state = (0, import_vue.shallowRef)(service.state);
  const unsubscribe = (0, import_store.subscribe)(service.state, () => {
    state.value = (0, import_store.snapshot)(service.state);
  });
  (0, import_vue.onUnmounted)(() => {
    unsubscribe?.();
  });
  (0, import_vue.watchEffect)(() => {
    service.setOptions({ actions });
  });
  if (context) {
    (0, import_vue.watch)(
      context,
      (ctx) => {
        service.setContext((0, import_vue.unref)(ctx));
      },
      { deep: true }
    );
  }
  return state;
}

// src/use-actor.ts
function useActor(service) {
  const state = useSnapshot(service);
  return [state, service.send];
}

// src/use-service.ts
var import_vue2 = require("vue");
function useService(machine, options) {
  const { state: hydratedState, context } = options ?? {};
  const service = typeof machine === "function" ? machine() : machine;
  if (context)
    service.setContext((0, import_vue2.unref)(context));
  service._created();
  (0, import_vue2.onMounted)(() => {
    service.start(hydratedState);
    (0, import_vue2.onBeforeUnmount)(() => {
      service.stop();
    });
  });
  return service;
}

// src/use-machine.ts
function useMachine(machine, options) {
  const service = useService(machine, options);
  const state = useSnapshot(service, options);
  return [state, service.send, service];
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  mergeProps,
  normalizeProps,
  useActor,
  useMachine,
  useSnapshot
});
//# sourceMappingURL=index.js.map